@@ -17,13 +17,13 @@
 from ConfigParser import SafeConfigParser
 from os import unlink, path, listdir, getcwd
 from string import Template
-from subprocess import Popen, PIPE
+from subprocess import Popen, PIPE, STDOUT
 from sys import stderr
 from tempfile import NamedTemporaryFile
 import errno
 import re
 
-COCCIGREP_VERSION = "1.11"
+COCCIGREP_VERSION = "1.13"
 
 have_multiprocessing = True
 try:
@@ -303,7 +303,7 @@ for p in p1:
         self.operations = {}
         self.process = []
         self.matches = []
-        self.options = []
+        self.options = ["--recursive-includes"]
         dirList = listdir(self.get_datadir())
         for fname in dirList:
             op = _operation_name(fname)
@@ -405,11 +405,10 @@ for p in p1:
         self.verbose = True
 
     def get_spatch_version(self):
-        cmd = [self.spatch] + [ '--version']
+        cmd = [self.spatch] + [ '-version']
         try:
-            output = Popen(cmd, stderr=PIPE).communicate()[1]
+            output = Popen(cmd, stdout=PIPE, stderr=STDOUT).communicate()[0]
         except OSError, err:
-            unlink(tmp_cocci_file_name)
             _raise_run_err(err, cmd)
         reg = r"version (.*?) with"
         m = re.search(reg, output)
@@ -438,8 +437,13 @@ for p in p1:
             raise CocciRunException("Can't use coccigrep without files "
                 "to search")
 
+        # get version of spatch
+        if self.spatch_newer_than("1.0.0-rc6"):
+            cocci_op = "=~"
+        else:
+            cocci_op = "~="
         # create tmp cocci file:
-        tmp_cocci_file = NamedTemporaryFile(suffix=".cocci")
+        tmp_cocci_file = NamedTemporaryFile(suffix=".cocci", delete=not self.verbose)
         tmp_cocci_file_name = tmp_cocci_file.name
         # open file with name matching operation
         cocci_file = open(self.operations[self.operation], 'r')
@@ -447,11 +451,6 @@ for p in p1:
         cocci_tmpl = cocci_file.read()
         cocci_smpl_tmpl = Template(cocci_tmpl)
         cocci_file.close()
-        # get version of spatch
-        if self.spatch_newer_than("1.0.0-rc6"):
-            cocci_op = "=~"
-        else:
-            cocci_op = "~="
         # do substitution
         cocci_smpl = cocci_smpl_tmpl.substitute(type=self.type,
             attribute=self.attribute, cocci_regexp_equal=cocci_op)
